theme_rotate: Rotate table or cell content

View source: R/theme_rotate.R

theme_rotateR Documentation

Rotate table or cell content

Description

In HTML, rotation is always applied to cell content (not the whole table) to keep borders intact. In LaTeX and Typst, when i and j are both NULL, the entire table is rotated; otherwise cell content is rotated.

Usage

theme_rotate(
  x,
  angle = get_option("tinytable_rotate_angle", default = 90),
  i = NULL,
  j = NULL,
  ...
)

Arguments

x

A tinytable object.

angle

Numeric. Rotation angle in degrees (0-360).

i

Row indices for cell rotation. When NULL (and j is also NULL), rotates the entire table in LaTeX/Typst or all cells in HTML.

j

Column indices for cell rotation. When NULL (and i is also NULL), rotates the entire table in LaTeX/Typst or all cells in HTML.

...

Additional arguments (ignored).

Value

A modified tinytable object.


tinytable documentation built on June 27, 2026, 1:06 a.m.