| theme_rotate | R Documentation |
In HTML, rotation is always applied to cell content (not the whole table) to
keep borders intact. In LaTeX and Typst, when i and j are both NULL,
the entire table is rotated; otherwise cell content is rotated.
theme_rotate(
x,
angle = get_option("tinytable_rotate_angle", default = 90),
i = NULL,
j = NULL,
...
)
x |
A |
angle |
Numeric. Rotation angle in degrees (0-360). |
i |
Row indices for cell rotation. When |
j |
Column indices for cell rotation. When |
... |
Additional arguments (ignored). |
A modified tinytable object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.