In HTML, rotation is always applied to cell content (not the whole table) to
keep borders intact. In LaTeX and Typst, when i and j are both NULL,
the entire table is rotated; otherwise cell content is rotated.
theme_rotate(
x,
angle = get_option("tinytable_rotate_angle", default = 90),
i = NULL,
j = NULL,
...
)A modified tinytable object.
A tinytable object.
Numeric. Rotation angle in degrees (0-360).
Row indices for cell rotation. When NULL (and j is also NULL),
rotates the entire table in LaTeX/Typst or all cells in HTML.
Column indices for cell rotation. When NULL (and i is also NULL),
rotates the entire table in LaTeX/Typst or all cells in HTML.
Additional arguments (ignored).