| theme_typst | R Documentation |
Typst-specific styles and options
theme_typst(
x,
multipage = get_option("tinytable_typst_multipage", default = FALSE),
figure = get_option("tinytable_typst_figure", default = TRUE),
portable = get_option("tinytable_typst_portable", default = NULL),
align_figure = get_option("tinytable_typst_align_figure", NULL),
resize_width = get_option("tinytable_typst_resize_width", 1),
resize_height = get_option("tinytable_typst_resize_height", default = NULL),
resize_direction = get_option("tinytable_typst_resize_direction", default = NULL),
...
)
x |
A |
multipage |
Logical. When |
figure |
Logical, whether to wrap the table in a Typst figure environment and block. |
portable |
Logical. Sets whether to create portable Typst output with base64-encoded local images embedded directly in the Typst code. Remote image URLs are not downloaded. |
align_figure |
Character string indicating horizontal alignment: "l", "c", or "r".
Defaults to |
resize_width |
Numeric value between 0.01 and 1.0 specifying the target width as a fraction of the available Typst layout width when resize_direction is specified. |
resize_height |
Numeric value between 0.01 and 1.0 specifying the target height as a fraction of the available Typst layout height. When specified, height controls the scaling and width scales proportionally. |
resize_direction |
Character string specifying how to resize tables. Options are: "down" to shrink oversized tables, "up" to expand undersized tables, and "both" to always scale to the target size. |
... |
Additional arguments. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.